<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2003-2005 Gary (gniemcew@yahoo.com)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once PATH_tslib . 'class.tslib_pibase.php';

/**
 * Plugin 'Page HTTPS (SSL) Enforcer' for the 'https_enforcer' extension.
 *
 * This class represents a simple way to enforce the http|s protocoll on
 * a per page basis.
 *
 * History
 *
 * 2004-09-09 - Michael Stucki <michael@typo3.org>
 * - Several updates and coding guidelines update (thanks!)
 * 
 * 2005-03-18 - Andreas Beutel <beutel@mehrwert.de>
 * - New option to disable enforcement for TYPO3 back end users
 * - Fix for the https://www.domain.tld/www.host.domain bug
 * - Added comments/documentation to all functions
 *
 * @author	Gary <gniemcew@yahoo.com>
 * @author	Michael Stucki <michael@typo3.org>
 * @author	Andreas Beutel <beutel@mehrwert.de>
 * @license	GPL
 */
class tx_httpsenforcer_pi1 extends tslib_pibase	{

	var $prefixId = 'tx_httpsenforcer_pi1';
	var $scriptRelPath = 'pi1/class.tx_httpsenforcer_pi1.php';
	var $extKey = 'https_enforcer';
	var $conf;

	/**
	 * The main function for this class; executed by TYPO3
	 *
	 * @param	string		Current content
	 * @param	array		Array with the configuration options
	 * @return	boolean		TRUE
	 * @access	public
	 */
	function main($content, $conf) {
		$this->conf = $conf;
		// 	check if http|s enforcment is enabled
		if ($this->conf['disable_httpsenforcer_for_be_user'] && $GLOBALS['BE_USER']->user) {
			return true;
		} else {
			if ($this->ext_requiresSSL() && !$this->ext_isSSL())	{
				$typo3_root = $this->conf['secure_typo3_root'];
				$url = 'https://' . $typo3_root . '/' . $this->ext_getBaseURI();
				$this->ext_hardRedirect($url);
			} elseif (!$this->ext_requiresSSL() && $this->ext_isSSL())	{
				$typo3_root = $this->conf['unsecure_typo3_root'];
				$url = 'http://' . $typo3_root . '/' . $this->ext_getBaseURI();
				$this->ext_hardRedirect($url);
			}
		}
		return true;
	}

	/**
	 * Check if the current page is already SSL encrypted
	 *
	 * @param	integer		Port number to check
	 * @return	boolean		TRUE if successful, FALSE otherwise
	 * @access	public
	 */
	function ext_isSSL($port = 443)	{
		if (@$GLOBALS['HTTP_SERVER_VARS']['SERVER_PORT'] != $port) {
			return false;
		} elseif (@$GLOBALS['HTTP_SERVER_VARS']['HTTPS'] != 'on')	{
			return false;
		} else {
			return true;
		}
	}

	/**
	 * Check if the current page does require SSL encryption
	 *
	 * @return	boolean		TRUE if SSL is required for this page, FALSE otherwise
	 * @access	public
	 */
	function ext_requiresSSL() {
		if($GLOBALS['TSFE']->page['tx_httpsenforcer_force_secure'] || $this->conf['require_ssl']) {
			return true;
		}
	}

	/**
	 * Send a redirect header
	 *
	 * @param	string		URL to redirect to
	 * @return	void
	 * @access	public
	 */
	function ext_hardRedirect($url)	{
		// header("HTTP 302 Redirect");
		header('Location: ' . $url);
		exit;
	}

	/**
	 * Get the base URI of the current page
	 *
	 * @return	string		The base URI
	 * @access	public
	 */
	function ext_getBaseURI()	{
		// If the baseURI matches the current hostname do not return a value.
		// Prevents the https://www.domain.tld/www.host.domain bug
		$baseURI = basename(t3lib_div::getIndpEnv('TYPO3_REQUEST_URL'));
		if (t3lib_div::getIndpEnv('TYPO3_HOST_ONLY') != $baseURI) {
			return $baseURI;
		} else {
			return null;
		}
	}
}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/https_enforcer/pi1/class.tx_httpsenforcer_pi1.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/https_enforcer/pi1/class.tx_httpsenforcer_pi1.php']);
}

?>
